@@ -8,7 +8,7 @@ use base 'Mail::Reporter';
 use Mail::Box::Message;
 use Mail::Box::Locker;
 
-our $VERSION = 2.00_20;
+our $VERSION = 2.003;
 
 use Carp;
 use Scalar::Util 'weaken';
@@ -894,10 +894,11 @@ sub current(;$)
 
     my $next = shift;
     if(my $previous = $self->{MB_current})
-    {    $previous->setLabel(current => 0);
+    {    $previous->label(current => 0);
     }
 
-    ($self->{MB_current} = $next)->setLabel(current => 1);
+    ($self->{MB_current} = $next)->label(current => 1);
+    $next;
 }
 
 
@@ -1153,7 +1154,7 @@ sub write(@)
 {   my ($self, %args) = @_;
 
     unless($args{force} || $self->writeable)
-    {   warn "Folder $self is opened read-only.\n";
+    {   $self->log(ERROR => "Folder $self is opened read-only.\n");
         return;
     }
 
@@ -1535,7 +1536,7 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-This code is beta, version 2.00_20.
+This code is beta, version 2.003.
 
 Copyright (c) 2001 Mark Overmeer. All rights reserved.
 This program is free software; you can redistribute it and/or modify
