@@ -3,7 +3,7 @@ use strict;
 package Mail::Box::MH;
 
 use base 'Mail::Box';
-our $VERSION = 2.00_20;
+our $VERSION = 2.003;
 
 use Mail::Box::MH::Index;
 use Mail::Box::MH::Message;
@@ -492,12 +492,14 @@ Create a index reader/writer object.
 sub index()
 {   my $self  = shift;
     return () unless $self->{MBM_keep_index};
+    return $self->{MBM_index} if defined $self->{MBM_index};
 
-    $self->{MBM_index_type}->new
+    $self->{MBM_index} = $self->{MBM_index_type}->new
      ( filename  => $self->{MBM_index_filename}
      , head_wrap => $self->{MB_head_wrap}
      , $self->logSettings
-     );
+     )
+
 }
 
 #-------------------------------------------
@@ -510,10 +512,12 @@ Create a label reader/writer object.
 
 sub labels()
 {   my $self   = shift;
-    $self->{MBM_labels_type}->new
+    return $self->{MBM_labels} if defined $self->{MBM_labels};
+
+    $self->{MBM_labels} = $self->{MBM_labels_type}->new
      ( filename => $self->{MBM_labels_filename}
      , $self->logSettings
-     );
+     )
 }
 
 #-------------------------------------------
@@ -573,6 +577,7 @@ sub readMessages(@)
         $head     ||= $self->{MBM_head_delayed_type}->new(@log);
 
         my $labref  = $labels ? $labels->get($msgnr) : undef;
+        unshift @$labref, seen => 1;
 
         my $message = $args{message_type}->new
          ( head      => $head
@@ -584,7 +589,7 @@ sub readMessages(@)
         my $body    = $args{body_delayed_type}->new(@log, message => $message);
         $message->storeBody($body);
 
-        $self->storeMessage($message) if $message;
+        $self->storeMessage($message);
     }
 
     $self->{MBM_highest_msgnr}  = $msgnrs[-1];
@@ -849,7 +854,7 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-This code is beta, version 2.00_20.
+This code is beta, version 2.003.
 
 Copyright (c) 2001 Mark Overmeer. All rights reserved.
 This program is free software; you can redistribute it and/or modify
