@@ -50,12 +50,11 @@ The general methods for C<Mail::Box::MH::Message> objects:
   MBM folder [FOLDER]                   MR reportAll [LEVEL]
    MM from|to|cc|bcc|date               MM send [MAILER], OPTIONS
    MM get FIELD                        MBM seqnr [INTEGER]
-   MM guessTimestamp                   MBM setLabel LIST
-   MM isDummy                          MBM shortString
-   MM isMultipart                       MM size
-   MM isPart                            MM subject
-  MBM label STRING [ ,STRING ,...]      MM timestamp
-  MBM labels                            MM toplevel
+   MM guessTimestamp                   MBM shortString
+   MM isDummy                           MM size
+   MM isMultipart                       MM subject
+   MM isPart                            MM timestamp
+   MM label LABEL [,VALUE]              MM toplevel
    MR log [LEVEL [,STRINGS]]            MR trace [LEVEL]
    MM messageId                         MR warnings
 
@@ -67,9 +66,10 @@ The extra methods for extension writers:
    MM clone                             MR notImplemented
    MM coerce MESSAGE                       parser
   MBM diskDelete                        MM read PARSER, [BODYTYPE]
-   MM head [HEAD]                      MBM readBody PARSER, HEAD [, BO...
+   MM head [HEAD, [LABELS]]            MBM readBody PARSER, HEAD [, BO...
    MR inGlobalDestruction               MM readHead PARSER [,CLASS]
    MM isDelayed                         MM storeBody BODY
+   MM labels                            MM takeMessageId [STRING]
 
 Methods prefixed with an abbreviation are described in the following
 manual-pages:
@@ -292,7 +292,7 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-This code is beta, version 2.00_20.
+This code is beta, version 2.003.
 
 Copyright (c) 2001 Mark Overmeer. All rights reserved.
 This program is free software; you can redistribute it and/or modify
