@@ -3,7 +3,7 @@ use strict;
 package Mail::Box::Mbox::Message;
 use base 'Mail::Box::Message';
 
-our $VERSION = 2.00_20;
+our $VERSION = 2.003;
 
 use POSIX 'SEEK_SET';
 use IO::InnerFile;
@@ -51,12 +51,11 @@ The general methods for C<Mail::Box::Mbox::Message> objects:
    MM from|to|cc|bcc|date               MR reportAll [LEVEL]
       fromLine [LINE]                   MM send [MAILER], OPTIONS
    MM get FIELD                        MBM seqnr [INTEGER]
-   MM guessTimestamp                   MBM setLabel LIST
-   MM isDummy                          MBM shortString
-   MM isMultipart                       MM size
-   MM isPart                            MM subject
-  MBM label STRING [ ,STRING ,...]      MM timestamp
-  MBM labels                            MM toplevel
+   MM guessTimestamp                   MBM shortString
+   MM isDummy                           MM size
+   MM isMultipart                       MM subject
+   MM isPart                            MM timestamp
+   MM label LABEL [,VALUE]              MM toplevel
    MR log [LEVEL [,STRINGS]]            MR trace [LEVEL]
    MM messageId                         MR warnings
 
@@ -69,9 +68,10 @@ The extra methods for extension writers:
    MM coerce MESSAGE                    MR notImplemented
   MBM diskDelete                           parser
       fileLocation                         read PARSER
-   MM head [HEAD]                      MBM readBody PARSER, HEAD [, BO...
+   MM head [HEAD, [LABELS]]            MBM readBody PARSER, HEAD [, BO...
    MR inGlobalDestruction               MM readHead PARSER [,CLASS]
    MM isDelayed                         MM storeBody BODY
+   MM labels                            MM takeMessageId [STRING]
 
 Methods prefixed with an abbreviation are described in the following
 manual-pages:
@@ -307,7 +307,7 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-This code is beta, version 2.00_20.
+This code is beta, version 2.003.
 
 Copyright (c) 2001 Mark Overmeer. All rights reserved.
 This program is free software; you can redistribute it and/or modify
