@@ -7,7 +7,7 @@ use base 'Mail::Message';
 use Date::Parse;
 use Scalar::Util 'weaken';
 
-our $VERSION = 2.00_20;
+our $VERSION = 2.003;
 
 =head1 NAME
 
@@ -59,24 +59,24 @@ The general methods for C<Mail::Box::Message> objects:
    MM from|to|cc|bcc|date               MR reportAll [LEVEL]
    MM get FIELD                         MM send [MAILER], OPTIONS
    MM guessTimestamp                       seqnr [INTEGER]
-   MM isDummy                              setLabel LIST
-   MM isMultipart                          shortString
-   MM isPart                            MM size
-      label STRING [ ,STRING ,...]      MM subject
-      labels                            MM timestamp
+   MM isDummy                              shortString
+   MM isMultipart                       MM size
+   MM isPart                            MM subject
+   MM label LABEL [,VALUE]              MM timestamp
    MR log [LEVEL [,STRINGS]]            MM toplevel
    MM messageId                         MR trace [LEVEL]
 
 The extra methods for extension writers:
 
-   MR AUTOLOAD                          MM isDelayed
+   MR AUTOLOAD                          MM labels
    MM DESTROY                           MR logPriority LEVEL
    MM body [BODY]                       MR logSettings
    MM clone                             MR notImplemented
    MM coerce MESSAGE                    MM read PARSER, [BODYTYPE]
       diskDelete                           readBody PARSER, HEAD [, BO...
-   MM head [HEAD]                       MM readHead PARSER [,CLASS]
+   MM head [HEAD, [LABELS]]             MM readHead PARSER [,CLASS]
    MR inGlobalDestruction               MM storeBody BODY
+   MM isDelayed                         MM takeMessageId [STRING]
 
 Methods prefixed with an abbreviation are described in the following
 manual-pages:
@@ -104,7 +104,6 @@ are supported:
  folder        Mail::Box::Message   <required>
  head          Mail::Message        undef
  head_wrap     Mail::Message        72
- labels        Mail::Box::Message   []
  log           Mail::Reporter       'WARNINGS'
  messageId     Mail::Message        undef
  modified      Mail::Message        0
@@ -137,11 +136,6 @@ C<Mail::Box::new(body_type)> for a detailed explanation.
 
 Is the file deleted from the start?
 
-=item * labels =E<gt> [ STRING =E<gt> VALUE, ... ]
-
-Set the specified labels to their accompanying value.  In most cases, this
-value will only be used as boolean, but it might be more complex.
-
 =item * size =E<gt> INTEGER
 
 The size of the message, which includes head and body, but without the
@@ -160,17 +154,11 @@ sub init($)
     $self->{MBM_body_type}  = $args->{body_type}
         if exists $args->{body_type};
 
-    $self->{MBM_labels}   ||= {};
     $self->{MBM_folder}     = $args->{folder};
     weaken($self->{MBM_folder});
 
     return $self if $self->isDummy;
 
-    $self->{MBM_labels} =
-      { seen => 1
-      , ($args->{labels} ? @{$args->{labels}} : ())
-      };
-
     $self;
 }
 
@@ -248,103 +236,6 @@ sub seqnr(;$)
 
 #-------------------------------------------
 
-=back
-
-=head2 Label management
-
-Labels are used to store knowledge about handling of the message within
-the folder.  Flags about whether a message was read, replied to, or
-(in some cases) scheduled for deletion.
-
-=over 4
-
-=item setLabel LIST
-
-The LIST is a set of scalars forming key,value pairs.
-
-=cut
-
-sub setLabel(@)
-{   my $self   = shift;
-    my $labels = $self->labels;
-    while(@_)
-    {   my $key = shift;          # order of two shifts in one line is not
-        $labels->{$key} = shift;  # defined.
-    }
-    $self->createStatus;
-    $self->{MM_modified}++;
-    $self;
-}
-
-#-------------------------------------------
-
-=item label STRING [ ,STRING ,...]
-
-Get the value related to the label(s).  This returns a list of values, which
-may be empty, undefined, or a value which evaluates to TRUE.
-
-Example:
-
-    if($message->label('seen')) {...}
-    my ($seen, $current) = $msg->label('seen', 'current');
-
-=cut
-
-sub label(@)
-{  my $self = shift;
-   wantarray
-   ? @{$self->{MBM_labels}}{@_}
-   : $self->{MBM_labels}{(shift)};
-}
-
-#-------------------------------------------
-
-=item labels
-
-Returns all known labels.  In SCALAR context, it returns the knowledge
-as reference to a hash.  This is a reference to the original data, but
-you shall *not* change that data directly: call C<setLabel()> for
-changes!
-
-In LIST context, you get a list of names which are defined.  Be warned
-that they will not all evaluate to true, although most of them will.
-
-=cut
-
-sub labels()
-{   my $self = shift;
-    wantarray ? keys %{$self->{MBM_labels}} : $self->{MBM_labels};
-}
-
-sub statusToLabels($)
-{   my ($self, $head) = @_;
-
-    my $labels = $self->{MBM_labels};
-    if(my $status = $head->get('status'))
-    {   $labels->{seen} = $status =~ /R/;
-        $labels->{old}  = $status =~ /O/;
-    }
-    if(my $xstatus = $head->get('x-status'))
-    {   $labels->{replied} = $xstatus =~ /A/;
-        $labels->{flagged} = $xstatus =~ /F/;
-    }
-    $self;
-}
-
-sub createStatus()
-{   my $self = shift;
-    my ($seen, $old, $replied, $flagged)
-       = $self->label( qw/seen old replied flagged/ );
-
-    my $head = $self->head;
-    $head->set('Status' => ($seen ? 'RO' : $old ? '0' : ''));
-    $head->set('X-Status' => ($replied ? 'A' : '').($flagged ? 'F' : ''));
-
-    $self;
-}
-
-#-------------------------------------------
-
 =item shortString
 
 Convert the message header to a short string, representing the most
@@ -405,12 +296,12 @@ sub copyTo($)
 
 #-------------------------------------------
 
-sub head(;$)
+sub head(;$$)
 {   my $self  = shift;
     return $self->{MM_head} unless @_;  #optimization
 
     my $old   = $self->{MM_head};
-    my $new   = $self->SUPER::head(shift);
+    my $new   = $self->SUPER::head(@_);
 
     return unless defined $new || defined $old;
 
@@ -431,15 +322,6 @@ sub head(;$)
 
 #-------------------------------------------
 
-sub readHead($;$)
-{   my $self = shift;
-    my $head = $self->SUPER::readHead(@_) or return;
-    $self->statusToLabels($head);
-    $head;
-}
-
-#-------------------------------------------
-
 =item readBody PARSER, HEAD [, BODYTYPE]
 
 Read the body of one message.  The PARSER gives access to the folder file.
@@ -456,7 +338,6 @@ folder where the message will be added to.
 sub readBody($$;$)
 {   my ($self, $parser, $head, $getbodytype) = @_;
 
-
     unless($getbodytype)
     {   my $folder   = $self->{MBM_folder};
         $getbodytype = sub {$folder->determineBodyType(@_)};
@@ -517,7 +398,7 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-This code is beta, version 2.00_20.
+This code is beta, version 2.003.
 
 Copyright (c) 2001 Mark Overmeer. All rights reserved.
 This program is free software; you can redistribute it and/or modify
