@@ -4,7 +4,7 @@ use strict;
 package Mail::Box::Message::Dummy;
 use base 'Mail::Box::Message';
 
-our $VERSION = 2.00_20;
+our $VERSION = 2.003;
 
 use Carp;
 
@@ -54,24 +54,24 @@ The general methods for C<Mail::Box::Message::Dummy> objects:
    MM from|to|cc|bcc|date               MR reportAll [LEVEL]
    MM get FIELD                         MM send [MAILER], OPTIONS
    MM guessTimestamp                   MBM seqnr [INTEGER]
-   MM isDummy                          MBM setLabel LIST
-   MM isMultipart                      MBM shortString
-   MM isPart                            MM size
-  MBM label STRING [ ,STRING ,...]      MM subject
-  MBM labels                            MM timestamp
+   MM isDummy                          MBM shortString
+   MM isMultipart                       MM size
+   MM isPart                            MM subject
+   MM label LABEL [,VALUE]              MM timestamp
    MR log [LEVEL [,STRINGS]]            MM toplevel
    MM messageId                         MR trace [LEVEL]
 
 The extra methods for extension writers:
 
-   MR AUTOLOAD                          MM isDelayed
+   MR AUTOLOAD                          MM labels
    MM DESTROY                           MR logPriority LEVEL
    MM body [BODY]                       MR logSettings
    MM clone                             MR notImplemented
    MM coerce MESSAGE                    MM read PARSER, [BODYTYPE]
   MBM diskDelete                       MBM readBody PARSER, HEAD [, BO...
-   MM head [HEAD]                       MM readHead PARSER [,CLASS]
+   MM head [HEAD, [LABELS]]             MM readHead PARSER [,CLASS]
    MR inGlobalDestruction               MM storeBody BODY
+   MM isDelayed                         MM takeMessageId [STRING]
 
 Methods prefixed with an abbreviation are described in the following
 manual-pages:
@@ -134,7 +134,7 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-This code is beta, version 2.00_20.
+This code is beta, version 2.003.
 
 Copyright (c) 2001 Mark Overmeer. All rights reserved.
 This program is free software; you can redistribute it and/or modify
