@@ -4,10 +4,11 @@ use warnings;
 package Mail::Box::Parser::Perl;
 use base 'Mail::Box::Parser';
 
+use Mail::Message::Field;
 use List::Util 'sum';
 use FileHandle;
 
-our $VERSION = 2.00_20;
+our $VERSION = 2.003;
 
 =head1 NAME
 
@@ -148,66 +149,67 @@ sub filePosition(;$)
 
 #------------------------------------------
 
-sub readHeader($$)
-{   my $self = shift;
-    my @ret  = ($self->filePosition, undef);
+sub readHeader($$$)
+{   my ($self, $wrap, $trust) = @_;
+    my @ret = ($self->filePosition, undef);
+    $trust = 1;
 
-    while(my ($field, $content) = $self->_read_header_line)
-    {   push @ret, $field, $content;
+LINE:
+    while(my $line = $self->_get_one_line)
+    {   last if !defined $line || $line eq "\n";
+
+        my ($name, $body) = split /\:\s*/, $line, 2;
+
+        unless(defined $body)
+        {   $self->log(WARNING => "Unexpected end of header:\n  $line");
+            $self->{MBPP_keep_line} = $line;
+            last LINE;
+        }
+    
+        # Do unfolding
+    
+        while(1)
+        {   my $newline = $self->_get_one_line;
+    
+            if( $newline eq "\n" || $newline !~ m/^\s/ )
+            {   $self->{MBPP_keep_line} = $newline;
+                last;
+            }
+    
+            $body .= $newline;
+            $line .= $newline;
+        }
+    
+        unless($trust)
+        {
+            $self->log(WARNING =>
+                "Blanks stripped after header fieldname: $name.")
+                    if $name =~ s/\s+$//;
+    
+            $self->log(WARNING => "Field $name is empty.")
+                unless length $body;
+        }
+
+        for($body)
+        {   s/\s+/ /g;
+            s/\s+$//;
+        }
+    
+        my ($comment, $folded);
+        if(Mail::Message::Field->isStructured($name))
+        {   ($body, $comment) = split /\s*\;\s*/, $body, 2;
+            $self->foldHeaderLine($line, $wrap);
+        }
+
+        push @ret, $name, $body, $comment, $folded;
     }
+
     $ret[1]  = $self->filePosition;
     @ret;
 }
 
 #------------------------------------------
 
-sub _read_header_line()
-{   my $self = shift;
-    my $line = $self->_get_one_line;
-
-    return () if !defined $line || $line eq "\n";
-
-    my ($name, $body) = split /\:\s*/, $line, 2;
-    unless(defined $body)
-    {   $self->log(WARNING => "Unexpected end of header:\n  $line");
-        $self->{MBPP_keep_line} = $line;
-        return ();
-    }
-
-    $self->log(WARNING => "Blanks stripped after header fieldname: $name.")
-        if $name =~ s/\s+$//;
-
-    # Do unfolding
-
-    while(1)
-    {   $line = $self->_get_one_line;
-
-        if($line eq "\n")
-        {   $self->{MBPP_keep_line} = $line;
-            last;
-        }
-
-        unless($line =~ m/^\s/)
-        {   $self->{MBPP_keep_line} = $line;
-            last;
-        }
-
-        $body .= $line;
-    }
-
-    for($body)
-    {   s/\s+/ /g;
-        s/ $//;
-    }
-
-    $self->log(WARNING => "Field $name is empty.")
-        if $body eq "\n";
-
-    ($name, $body);
-}
-
-#------------------------------------------
-
 sub foldHeaderLine($$)
 {   my ($self, $original, $wrap) = (shift, shift, shift);
     my @lines;
@@ -441,7 +443,7 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-This code is beta, version 2.00_20.
+This code is beta, version 2.003.
 
 Copyright (c) 2001 Mark Overmeer. All rights reserved.
 This program is free software; you can redistribute it and/or modify
