@@ -352,7 +352,7 @@ sub expand(;$)
         unless @_;
 
     my $fold = not shift;
-    $_->setLabel(folded => $fold) foreach $self->message;
+    $_->label(folded => $fold) foreach $self->message;
     $fold;
 }
 
@@ -601,7 +601,7 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-This code is beta, version 2.00_20.
+This code is beta, version 2.003.
 
 Copyright (c) 2001 Mark Overmeer. All rights reserved.
 This program is free software; you can redistribute it and/or modify
