@@ -9,7 +9,7 @@ use Mail::Message::Head::Complete;
 
 use Carp;
 
-our $VERSION = 2.00_20;
+our $VERSION = 2.003;
 
 =head1 NAME
 
@@ -51,34 +51,34 @@ header- and C<decoded()> to get the intented content of a message.
 
 The general methods for C<Mail::Message> objects:
 
-  MMC bounce OPTIONS                       nrLines
-  MMC build [MESSAGE|BODY], CONTENT        parent
-  MMC buildFromBody BODY, HEADERS          parts
-      decoded OPTIONS                      print [FILEHANDLE]
-      destinations                         printUndisclosed [FILEHANDLE]
-      encode OPTIONS                   MMC quotePrelude [STRING|FIELD]
-   MR errors                           MMC reply OPTIONS
-      from|to|cc|bcc|date              MMC replySubject STRING
-      get FIELD                         MR report [LEVEL]
-      guessTimestamp                    MR reportAll [LEVEL]
-      isDummy                              send [MAILER], OPTIONS
-      isMultipart                          size
-      isPart                               subject
+  MMC bounce OPTIONS                       new OPTIONS
+  MMC build [MESSAGE|BODY], CONTENT        nrLines
+  MMC buildFromBody BODY, HEADERS          parent
+      decoded OPTIONS                      parts
+      destinations                         print [FILEHANDLE]
+      encode OPTIONS                       printUndisclosed [FILEHANDLE]
+   MR errors                           MMC quotePrelude [STRING|FIELD]
+      from|to|cc|bcc|date              MMC reply OPTIONS
+      get FIELD                        MMC replySubject STRING
+      guessTimestamp                    MR report [LEVEL]
+      isDummy                           MR reportAll [LEVEL]
+      isMultipart                          send [MAILER], OPTIONS
+      isPart                               size
+      label LABEL [,VALUE]                 subject
    MR log [LEVEL [,STRINGS]]               timestamp
       messageId                            toplevel
       modified [BOOL]                   MR trace [LEVEL]
-      new OPTIONS                       MR warnings
 
 The extra methods for extension writers:
 
-   MR AUTOLOAD                          MR logPriority LEVEL
-      DESTROY                           MR logSettings
-      body [BODY]                       MR notImplemented
-      clone                                read PARSER, [BODYTYPE]
-      coerce MESSAGE                       readBody PARSER, HEAD [, BO...
-      head [HEAD]                          readHead PARSER [,CLASS]
-   MR inGlobalDestruction                  storeBody BODY
-      isDelayed                            takeMessageId [STRING]
+   MR AUTOLOAD                             labels
+      DESTROY                           MR logPriority LEVEL
+      body [BODY]                       MR logSettings
+      clone                             MR notImplemented
+      coerce MESSAGE                       read PARSER, [BODYTYPE]
+      head [HEAD, [LABELS]]                readBody PARSER, HEAD [, BO...
+   MR inGlobalDestruction                  readHead PARSER [,CLASS]
+      isDelayed                            storeBody BODY
 
 Methods prefixed with an abbreviation are described in the following
 manual-pages:
@@ -102,6 +102,7 @@ be read later, unless specified at construction.
  OPTION            DESCRIBED IN       DEFAULT
  body              Mail::Message      undef
  head              Mail::Message      undef
+ labels            Mail::Message      []
  log               Mail::Reporter     'WARNINGS'
  messageId         Mail::Message      undef
  modified          Mail::Message      0
@@ -142,6 +143,11 @@ Default type of head to be created for C<readHead()>.
 
 The soft maximum line width of header lines in the folder to write.
 
+=item * labels =E<gt> [ STRING =E<gt> VALUE, ... ]
+
+Set the specified labels to their accompanying value.  In most cases, this
+value will only be used as boolean, but it might be more complex.
+
 =item * messageId =E<gt> STRING
 
 The id on which this message can be recognized.  If none specified and
@@ -175,7 +181,7 @@ sub init($)
 
     my $head;
     if(defined($head = $args->{head}))
-    {   $self->head($head);
+    {   $self->head($head, $args->{labels});
     }
     elsif(my $msgid = $args->{messageId} || $args->{messageID})
     {   $self->takeMessageId($msgid);
@@ -703,6 +709,37 @@ sub AUTOLOAD(@)
 
 #------------------------------------------
 
+=item label LABEL [,VALUE]
+
+Return the value of the LABEL, optionally after setting it to VALUE.  If
+the VALUE is C<undef> then the label is removed.
+
+Labels are used to store knowledge about handling of the message within
+the folder.  Flags about whether a message was read, replied to, or
+(in some cases) scheduled for deletion.
+
+Some labels are taken from the header's C<Status> and C<X-Status> lines,
+however folder types like MH define a seperate label file.
+
+Examples:
+
+ print $message->label('seen');
+ if($message->label('seen')) {...};
+ $message->label(seen => 1);
+
+=cut
+
+sub label($;$)
+{   my ($self, $label) = (shift, shift);
+    if(@_)
+    {   $self->{MM_labels}{$label} = shift;
+        $self->head->createStatus($label);
+    }
+    $self->{MM_labels}{$label};
+}
+
+#------------------------------------------
+
 =back
 
 =head1 METHODS for extension writers
@@ -759,9 +796,8 @@ which returns a body-class based on the header.
 sub read($;$)
 {   my ($self, $parser, $bodytype) = @_;
 
-    my $head         = $self->readHead($parser) or return;
+    my $head = $self->readHead($parser) or return;
     $self->head($head);
-#warn "Subject: ", $self->get('subject'), "\n";
 
     $self->{MM_body} = $self->readBody($parser, $head, $bodytype);
     $self;
@@ -929,10 +965,13 @@ sub storeBody($)
 
 #------------------------------------------
 
-=item head [HEAD]
+=item head [HEAD, [LABELS]]
 
 Return (optionally after setting) the HEAD of this message.
 The head must be an (sub-)class of C<Mail::Message::Head>.
+When the head is added, status information is taken from it
+and transformed into labels.  More labels can be added by the
+LABALS hash.  They are added later.
 
 Example:
 
@@ -940,25 +979,38 @@ Example:
 
 =cut
 
-sub head(;$)
+sub head(;$$)
 {   my $self = shift;
     return $self->{MM_head} unless @_;
 
     my $head = shift;
     return delete $self->{MM_head} unless defined $head;
 
+    my $labels = shift;
+
     $self->log(INTERNAL => "wrong type of head for $self")
         unless ref $head && $head->isa('Mail::Message::Head');
 
     $head->message($self);
 
-    my $old = $self->{MM_head};
-    $self->{MM_modified}++ if defined $old && !$old->isDelayed;
+    if(my $old = $self->{MM_head})
+    {   $self->{MM_modified}++ unless $old->isDelayed;
+    }
 
     $self->{MM_head} = $head;
 
-    $self->takeMessageId
-        unless $head->isDelayed;
+    unless($head->isDelayed)
+    {  $self->takeMessageId;
+       my %labels = $head->statusLabels;
+       if(exists $self->{MM_labels})
+            { @{$self->{MM_labels}}{keys %labels} = values %labels }
+       else { $self->{MM_labels} = \%labels }
+    }
+
+    if($labels)
+    {   my %labels = @$labels;
+        @{$self->{MM_labels}}{keys %labels} = values %labels;
+    }
 
     $head;
 }
@@ -1088,6 +1140,26 @@ confess "@_" unless $message;
 
 #------------------------------------------
 
+
+=item labels
+
+Returns all known labels.  In SCALAR context, it returns the knowledge
+as reference to a hash.  This is a reference to the original data, but
+you shall *not* change that data directly: call C<label> for
+changes!
+
+In LIST context, you get a list of names which are defined.  Be warned
+that they will not all evaluate to true, although most of them will.
+
+=cut
+
+sub labels()
+{   my $self = shift;
+    wantarray ? keys %{$self->{MM_labels}} : $self->{MM_labels};
+}
+
+#------------------------------------------
+
 =item DESTROY
 
 When a message is to accessible anymore by any user's reference, Perl
@@ -1122,7 +1194,7 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-This code is beta, version 2.00_20.
+This code is beta, version 2.003.
 
 Copyright (c) 2001 Mark Overmeer. All rights reserved.
 This program is free software; you can redistribute it and/or modify
