@@ -7,7 +7,7 @@ use base 'Mail::Message::Body';
 use Mail::Message::Body::Lines;
 use Mail::Message::Part;
 
-our $VERSION = 2.00_20;
+our $VERSION = 2.003;
 
 use Carp;
 
@@ -431,7 +431,7 @@ Examples:
 
 =cut
 
-sub parts(@) { @{shift->{MMBM_parts}} }
+sub parts() { @{shift->{MMBM_parts}} }
 
 #-------------------------------------------
 
@@ -585,13 +585,14 @@ sub clone()
     my $preamble = $self->preamble;
     my $epilogue = $self->epilogue;
 
-    ref($self)->new
+    my $body     = ref($self)->new
      ( $self->logSettings
      , based_on => $self
      , preamble => ($preamble ? $preamble->clone : undef)
      , epilogue => ($epilogue ? $epilogue->clone : undef)
-     , parts    => [ map {$_->clone} $self->parts ]
+     , parts    => [ map {$_->clone} $self->parts]
      );
+
 }
 
 #-------------------------------------------
@@ -610,7 +611,7 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-This code is beta, version 2.00_20.
+This code is beta, version 2.003.
 
 Copyright (c) 2001 Mark Overmeer. All rights reserved.
 This program is free software; you can redistribute it and/or modify
