@@ -5,7 +5,7 @@ use strict;
 
 package Mail::Message;
 
-our $VERSION = 2.00_20;
+our $VERSION = 2.003;
 
 use Mail::Message::Head::Complete;
 use Mail::Message::Body::Lines;
@@ -367,6 +367,7 @@ sub reply(@)
     # Ready
 
     $self->log(PROGRESS => 'Reply created from '.$origid);
+    $self->label(replied => 1);
     $reply;
 }
 
@@ -714,7 +715,7 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-This code is beta, version 2.00_20.
+This code is beta, version 2.003.
 
 Copyright (c) 2001 Mark Overmeer. All rights reserved.
 This program is free software; you can redistribute it and/or modify
