@@ -6,7 +6,7 @@ use base 'Mail::Message::Field';
 
 use Carp;
 
-our $VERSION = 2.00_20;
+our $VERSION = 2.003;
 
 =head1 NAME
 
@@ -107,12 +107,12 @@ sub new($;$$@)
 
     if(defined $comment && length $comment)
     {   # A comment is defined, so shouldn't be in body.
-        confess "A header-body cannot contain a semi-colon in $body."
+        warn "A header-body cannot contain a semi-colon in $body."
             if $body =~ m/\;/;
     }
     elsif(__PACKAGE__->isStructured($name))
     {   # try strip comment from field-body.
-        $comment = $body =~ s/\s*\;\s*(.*)$// ? $1 : undef;
+        ($body, $comment) = split /\s*\;\s*/, $body, 2;
     }
 
     #
@@ -184,7 +184,7 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-This code is beta, version 2.00_20.
+This code is beta, version 2.003.
 
 Copyright (c) 2001 Mark Overmeer. All rights reserved.
 This program is free software; you can redistribute it and/or modify
