@@ -12,7 +12,7 @@ use Carp;
 use Scalar::Util 'weaken';
 use FileHandle;
 
-our $VERSION = 2.00_20;
+our $VERSION = 2.003;
 
 use overload bool => sub { keys %{shift->{MMH_fields}} };
 
@@ -97,9 +97,10 @@ The extra methods for extension writers:
       clone [FIELDS]                    MR logSettings
       createFromLine                       message [MESSAGE]
       createMessageId                      moveLocation DISTANCE
-      fileLocation                      MR notImplemented
-      grepNames [NAMES|ARRAY-OF-N...       read PARSER
-      guessBodySize                        setNoRealize FIELD
+      createStatus LABEL                MR notImplemented
+      fileLocation                         read PARSER
+      grepNames [NAMES|ARRAY-OF-N...       setNoRealize FIELD
+      guessBodySize                        statusLabels
       guessTimestamp                       wrapLength [CHARS]
 
 Prefixed methods are described in   MR = L<Mail::Reporter>.
@@ -512,21 +513,17 @@ passes the PARSER as an argument.  Do not call this method yourself!
 sub read($)
 {   my ($self, $parser) = @_;
 
-    my $pairs     = [ $parser->readHeader($self->{MMH_wrap_length}) ];
-    @$self{ qw/MMH_begin MMH_end/ } = splice @$pairs, 0, 2;
-#   return unless @$pairs;
+    my $quad  = [ $parser->readHeader($self->{MMH_wrap_length}) ];
+    @$self{ qw/MMH_begin MMH_end/ } = splice @$quad, 0, 2;
 
     $parser->defaultParserType(ref $parser);
 
     my $known     = $self->{MMH_fields};
-    my $wrap      = $self->{MMH_wrap_length};
     my $fieldtype = $self->{MMH_field_type} || 'Mail::Message::Field::Fast';
 
-    while(@$pairs)
-    {   my ($name, $body) = (shift @$pairs, shift @$pairs);
-        my $field = $fieldtype->new($name, $body);
-        $field->setWrapLength($wrap);
-        $name     = lc $name;
+    while(@$quad)
+    {   my $field = $fieldtype->newNoCheck(splice @$quad, 0, 4);
+        my $name  = $field->name;
 
         push @{$self->{MMH_order}}, $name
             unless exists $known->{$name};
@@ -782,6 +779,60 @@ sub addNoRealize($)
     $field;
 }
 
+#-------------------------------------------
+
+=item statusLabels
+
+Returns a list of key values pairs which show how the C<Status> and
+C<X-Status> header lines are to be represented in labels.
+
+=cut
+
+sub statusLabels($)
+{   my $self  = shift;
+
+    my $status  = $self->get('status')   || '';
+    my $xstatus = $self->get('x-status') || '';
+
+    ( seen    => ($status  =~ /R/ ? 1 : 0)
+    , old     => ($status  =~ /O/ ? 1 : 0)
+    , replied => ($xstatus =~ /A/ ? 1 : 0)
+    , flagged => ($xstatus =~ /F/ ? 1 : 0)
+    );
+}
+
+#------------------------------------------
+
+=item createStatus LABEL
+
+The LABEL changes, and therefor the C<Status> or C<X-Status> lines of the
+header may need an update.  If the LABEL is not used for a header line,
+the call is ignored.
+
+=cut
+
+sub createStatus($)
+{   my ($self, $label) = @_;
+
+    if($label eq "seen")
+    {   my $status = $self->get('status') || '';
+        $self->set(Status => 'RO') if $status !~ /R/;
+    }
+    elsif($label eq "old")
+    {   my $status = $self->get('status') || '';
+        $self->set(Status => $status.'O') if $status !~ /O/;
+    }
+    elsif($label eq "replied")
+    {   my $xstatus = $self->get('x-status') || '';
+        $self->set('X-Status' => $xstatus.'A') if $xstatus !~ /A/;
+    }
+    elsif($label eq "flagged")
+    {   my $xstatus = $self->get('x-status') || '';
+        $self->set('X-Status' => $xstatus.'F') if $xstatus !~ /F/;
+    }
+
+    $self;
+}
 #------------------------------------------
 
 =head1 SEE ALSO
@@ -796,7 +847,7 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-This code is beta, version 2.00_20.
+This code is beta, version 2.003.
 
 Copyright (c) 2001 Mark Overmeer. All rights reserved.
 This program is free software; you can redistribute it and/or modify
