@@ -10,7 +10,7 @@ use Object::Realize::Later
     realize        => 'load',
     believe_caller => 1;
 
-our $VERSION = 2.00_20;
+our $VERSION = 2.003;
 
 use Carp;
 use Date::Parse;
@@ -72,9 +72,10 @@ The extra methods for extension writers:
   MMH clone [FIELDS]                    MR logSettings
   MMH createFromLine                   MMH message [MESSAGE]
   MMH createMessageId                  MMH moveLocation DISTANCE
-  MMH fileLocation                      MR notImplemented
-  MMH grepNames [NAMES|ARRAY-OF-N...   MMH read PARSER
-  MMH guessBodySize                        setNoRealize FIELD
+  MMH createStatus LABEL                MR notImplemented
+  MMH fileLocation                     MMH read PARSER
+  MMH grepNames [NAMES|ARRAY-OF-N...       setNoRealize FIELD
+  MMH guessBodySize                    MMH statusLabels
   MMH guessTimestamp                   MMH wrapLength [CHARS]
 
 Methods prefixed with an abbreviation are described in the following
@@ -243,7 +244,7 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-This code is beta, version 2.00_20.
+This code is beta, version 2.003.
 
 Copyright (c) 2001 Mark Overmeer. All rights reserved.
 This program is free software; you can redistribute it and/or modify
