@@ -4,7 +4,7 @@ use warnings;
 package Mail::Message::Part;
 use base 'Mail::Message';
 
-our $VERSION = 2.00_20;
+our $VERSION = 2.003;
 
 use Carp;
 
@@ -44,34 +44,34 @@ into mail-folder-specific variants.
 
 The general methods for C<Mail::Message::Part> objects:
 
-  MMC bounce OPTIONS                    MM nrLines
-  MMC build [MESSAGE|BODY], CONTENT     MM parent
-      buildFromBody BODY, MULTIPA...    MM parts
-   MM decoded OPTIONS                   MM print [FILEHANDLE]
-   MM destinations                      MM printUndisclosed [FILEHANDLE]
-   MM encode OPTIONS                   MMC quotePrelude [STRING|FIELD]
-   MR errors                           MMC reply OPTIONS
-   MM from|to|cc|bcc|date              MMC replySubject STRING
-   MM get FIELD                         MR report [LEVEL]
-   MM guessTimestamp                    MR reportAll [LEVEL]
-   MM isDummy                           MM send [MAILER], OPTIONS
-   MM isMultipart                       MM size
-   MM isPart                            MM subject
+  MMC bounce OPTIONS                       new OPTIONS
+  MMC build [MESSAGE|BODY], CONTENT     MM nrLines
+      buildFromBody BODY, MULTIPA...    MM parent
+   MM decoded OPTIONS                   MM parts
+   MM destinations                      MM print [FILEHANDLE]
+   MM encode OPTIONS                    MM printUndisclosed [FILEHANDLE]
+   MR errors                           MMC quotePrelude [STRING|FIELD]
+   MM from|to|cc|bcc|date              MMC reply OPTIONS
+   MM get FIELD                        MMC replySubject STRING
+   MM guessTimestamp                    MR report [LEVEL]
+   MM isDummy                           MR reportAll [LEVEL]
+   MM isMultipart                       MM send [MAILER], OPTIONS
+   MM isPart                            MM size
+   MM label LABEL [,VALUE]              MM subject
    MR log [LEVEL [,STRINGS]]            MM timestamp
    MM messageId                         MM toplevel
    MM modified [BOOL]                   MR trace [LEVEL]
-      new OPTIONS                       MR warnings
 
 The extra methods for extension writers:
 
-   MR AUTOLOAD                          MR logPriority LEVEL
-   MM DESTROY                           MR logSettings
-   MM body [BODY]                       MR notImplemented
-   MM clone                             MM read PARSER, [BODYTYPE]
-      coerce BODY|MESSAGE, MULTIPART    MM readBody PARSER, HEAD [, BO...
-   MM head [HEAD]                       MM readHead PARSER [,CLASS]
-   MR inGlobalDestruction               MM storeBody BODY
-   MM isDelayed                         MM takeMessageId [STRING]
+   MR AUTOLOAD                          MM labels
+   MM DESTROY                           MR logPriority LEVEL
+   MM body [BODY]                       MR logSettings
+      clone                             MR notImplemented
+      coerce BODY|MESSAGE, MULTIPART    MM read PARSER, [BODYTYPE]
+   MM head [HEAD, [LABELS]]             MM readBody PARSER, HEAD [, BO...
+   MR inGlobalDestruction               MM readHead PARSER [,CLASS]
+   MM isDelayed                         MM storeBody BODY
 
 Methods prefixed with an abbreviation are described in the following
 manual-pages:
@@ -197,6 +197,25 @@ sub coerce($@)
 
 #------------------------------------------
 
+=item clone
+
+A message part is cloned as plain message, and may be added as such
+to a folder.  It will be coerced into a part when added to a multi-part
+body.
+
+=cut
+
+sub clone()
+{   my $self = shift;
+    Mail::Message->new
+     ( body  => $self->body->clone
+     , head  => $self->head->clone
+     , $self->logSettings
+     );
+}
+
+#------------------------------------------
+
 =back
 
 =head1 SEE ALSO
@@ -211,7 +230,7 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-This code is beta, version 2.00_20.
+This code is beta, version 2.003.
 
 Copyright (c) 2001 Mark Overmeer. All rights reserved.
 This program is free software; you can redistribute it and/or modify
